MultiRecipientEncryption

Struct MultiRecipientEncryption 

pub struct MultiRecipientEncryption<G: GroupElement> {
    pub proof: DdhTupleNizk<G>,
    /* private fields */
}
Simple ECIES encryption using a generic group and AES-256-counter.

Random oracles are extended from two oracles provided by the caller, one for encryptions/decryptions and one for recovery packages. We assume that the caller extended the random oracles with the relevant tags and omit them here.

The encryption uses AES Counter mode and is not CCA secure as is.

Multi-recipient encryption with a proof-of-possession of the ephemeral key.

Fields

proof: DdhTupleNizk<G>

Implementations

Source

impl<G> MultiRecipientEncryption<G>

pub fn encrypt<R: AllowedRng>( pk_and_msgs: &[(PublicKey<G>, Vec<u8>)], encryption_random_oracle: &RandomOracle, rng: &mut R, ) -> MultiRecipientEncryption<G>

pub fn verify( &self, encryption_random_oracle: &RandomOracle, ) -> FastCryptoResult<()>

pub fn decrypt( &self, sk: &PrivateKey<G>, encryption_random_oracle: &RandomOracle, receiver_index: usize, ) -> Vec<u8>

We assume that verify is called before decrypt and do not call it again here to avoid redundant checks.

pub fn create_recovery_package<R: AllowedRng>( &self, sk: &PrivateKey<G>, recovery_random_oracle: &RandomOracle, rng: &mut R, ) -> RecoveryPackage<G>

We assume that verify is called before decrypt and do not call it again here to avoid redundant checks.

pub fn decrypt_with_recovery_package( &self, pkg: &RecoveryPackage<G>, recovery_random_oracle: &RandomOracle, encryption_random_oracle: &RandomOracle, receiver_pk: &PublicKey<G>, receiver_index: usize, ) -> FastCryptoResult<Vec<u8>>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn ephemeral_key(&self) -> &G

pub fn proof(&self) -> &DdhTupleNizk<G>