pub struct RandomOracle { /* private fields */ }Expand description
Random Oracle from SHA3-512.
- prefix should be globally unique.
- evaluate serializes the given input and outputs SHA3-512(prefix_len as big-endian u32 | prefix | input).
- Subprotocols may use a prefix that is extended from the prefix of its parent protocol, by deriving a new instance using extend, which simply concatenates the strings with the separator “-”. E.g., RandomOracle::new(“abc”).extend(“def”) = RandomOracle::new(“abc-def”).
The caller must make sure to:
- Choose distinct prefix & extension strings, preferably without “-” in them (asserted in debug mode).
- Ensure that the length of prefix & extension is small enough to fit in u32. Violating this constraint will cause a panic.
Implementations